@@ -1,18 +1,19 @@
 import logging
 from http import HTTPStatus
-from typing import Iterable, Mapping, Optional, Union
-from flask import current_app as app
+from typing import Iterable, Mapping, Optional, Union, Dict, List, Any  # noqa: F401
 
+from amundsen_common.models.dashboard import DashboardSummarySchema
 from amundsen_common.models.popular_table import PopularTableSchema
 from amundsen_common.models.user import UserSchema
 from flasgger import swag_from
+from flask import current_app as app
 from flask_restful import Resource
 
 from metadata_service.api import BaseAPI
+from metadata_service.entity.resource_type import to_resource_type, ResourceType
 from metadata_service.exception import NotFoundException
 from metadata_service.proxy import get_proxy_client
 from metadata_service.util import UserResourceRel
-from metadata_service.entity.resource_type import to_resource_type
 
 LOGGER = logging.getLogger(__name__)
 
@@ -57,9 +58,24 @@ class UserFollowsAPI(Resource):
         try:
             resources = self.client.get_table_by_user_relation(user_email=user_id,
                                                                relation_type=UserResourceRel.follow)
-            if len(resources['table']) > 0:
-                return {'table': PopularTableSchema(many=True).dump(resources['table']).data}, HTTPStatus.OK
-            return {'table': []}, HTTPStatus.OK
+
+            table_key = ResourceType.Table.name.lower()
+            dashboard_key = ResourceType.Dashboard.name.lower()
+            result = {
+                table_key: [],
+                dashboard_key: []
+            }  # type: Dict[str, List[Any]]
+
+            if resources and table_key in resources and len(resources[table_key]) > 0:
+                result[table_key] = PopularTableSchema(many=True).dump(resources[table_key]).data
+
+            resources = self.client.get_dashboard_by_user_relation(user_email=user_id,
+                                                                   relation_type=UserResourceRel.follow)
+
+            if resources and dashboard_key in resources and len(resources[dashboard_key]) > 0:
+                result[dashboard_key] = DashboardSummarySchema(many=True).dump(resources[dashboard_key]).data
+
+            return result, HTTPStatus.OK
 
         except NotFoundException:
             return {'message': 'user_id {} does not exist'.format(user_id)}, HTTPStatus.NOT_FOUND
@@ -102,8 +118,7 @@ class UserFollowAPI(Resource):
             return {'message': 'The user {} for id {} resource type {}'
                                'is not added successfully'.format(user_id,
                                                                   resource_id,
-                                                                  resource_type)}, \
-                HTTPStatus.INTERNAL_SERVER_ERROR
+                                                                  resource_type)}, HTTPStatus.INTERNAL_SERVER_ERROR
 
     @swag_from('swagger_doc/user/follow_delete.yml')
     def delete(self, user_id: str, resource_type: str, resource_id: str) -> Iterable[Union[Mapping, int, None]]:
@@ -128,8 +143,7 @@ class UserFollowAPI(Resource):
             return {'message': 'The user {} for id {} resource type {} '
                                'is not deleted successfully'.format(user_id,
                                                                     resource_id,
-                                                                    resource_type)}, \
-                HTTPStatus.INTERNAL_SERVER_ERROR
+                                                                    resource_type)}, HTTPStatus.INTERNAL_SERVER_ERROR
 
 
 class UserOwnsAPI(Resource):
